
.. _`Python`: https://www.python.org/
.. _`Tratamento de Exceções`: https://docs.python.org/3.6/tutorial/errors.html#handling-exceptions
.. _`Flask`: http://flask.pocoo.org/
.. _`Pipenv`: https://pipenv.readthedocs.io/
.. _`tox`: https://tox.readthedocs.io/

.. _`SATComum`: https://github.com/base4sistemas/satcomum
.. _`SATCFe`: https://github.com/base4sistemas/satcfe
.. _`SATHub`: https://github.com/base4sistemas/sathub
.. _`SATExtrato`: https://github.com/base4sistemas/satextrato
.. _`PyESCPOS`: https://github.com/base4sistemas/pyescpos

.. _`SEFAZ/SP`: http://www.fazenda.sp.gov.br/
.. _`Portaria CAT 147`: https://portal.fazenda.sp.gov.br/servicos/sat/Paginas/Legislacao.aspx
.. _`CAT 147`: `Portaria CAT 147`_
.. _`ICP Brasil`: http://www.iti.gov.br/icp-brasil

.. _`XML`: http://www.w3.org/XML/
.. _`pipe`: http://unicode-table.com/en/007C/
.. _`GNU Make`: https://www.gnu.org/software/make/
.. _`GNU GCC`: https://gcc.gnu.org/


.. |copy| unicode:: U+00A9 .. COPYRIGHT SIGN
    :ltrim:

.. |reg|  unicode:: U+00AE .. REGISTERED SIGN
    :ltrim:

.. |trade|  unicode:: U+2122 .. TRADE MARK SIGN
    :ltrim:
